@@ -17,9 +17,7 @@ import lib
 # /check    (GET)  -> checks if a given key is in the trie
 # /view     (GET)  -> returns a list of words from the tree
 
-
-
-if __name__ == "__main__":
+def main():
     shell = Nubia(
             name="Trie CLI",
             command_pkgs=lib,
